# Archiving Notice
**This project is being archived as of `Wednesday, 17th December 2025`. While the code works in its current state, there are some known issues that will no longer be addressed or maintained. Unfortunately, after reaching version 7.1.*, I realized that I don’t have the time to continue developing or maintaining it. Despite having started work on version 8.0, I’ve had to make the tough decision to stop active development due to time constraints and an inability to secure the support needed to move things forward.**

**As part of this, I will be removing the Snap package from the store. The PyPI package will remain available, and the full source code will continue to be accessible, with the canonical repository migrating to [Codeberg](https://codeberg.org/knewkarma/knewkarma). The GitHub repository will remain as a mirror for those who wish to fork or reference it.**

**Thank you to everyone who contributed, tested, and used this project. It was a great experience, and I’m proud of what it accomplished, even though it’s not evolving further.**

**Feel free to fork and maintain it as you wish!**

---

**Knew Karma** (*/nuː ‘kɑːrmə/*) is a data analysis toolkit designed to provide an extensive range of functionalities
for exploring and analysing Reddit data.
<p align="center">
  <a href="https://github.com/knewkarma-io/knewkarma"><img alt="Code Style" src="https://img.shields.io/badge/code%20style-black-000000?logo=github&link=https%3A%2F%2Fgithub.com%2Frly0nheart%2Fknewkarma"></a>
  <a href="https://pepy.tech/project/knewkarma"><img alt="Downloads" src="https://img.shields.io/pepy/dt/knewkarma?logo=pypi"></a>
  <a href="https://pypi.org/project/knewkarma"><img alt="PyPI - Version" src="https://img.shields.io/pypi/v/knewkarma?logo=pypi&link=https%3A%2F%2Fpypi.org%2Fproject%2Fknewkarma"></a>
  <a href="https://snapcraft.io/knewkarma"><img alt="Snap Version" src="https://img.shields.io/snapcraft/v/knewkarma/latest/stable?logo=snapcraft&color=%23BB431A"></a>
  <!--<a href="https://opencollective.com/knewkarma"><img alt="Open Collective backers and sponsors" src="https://img.shields.io/opencollective/all/knewkarma?logo=open-collective"></a>-->
</p>

```commandline
knewkarma subreddit AskScience --posts --export=json,csv,html
```

Or

```commandline
rsubreddit AskScience --posts
````

## Documentation

Refer to the [documentation](https://knewkarma.readthedocs.io) for *Feature Overview*, *Installation*, *API
Integration*, and *Usage* instructions.

## Star History

<a href="https://star-history.com/#knewkarma-io/knewkarma&Date">
   <picture>
      <source media="(prefers-color-scheme: dark)" srcset="https://api.star-history.com/svg?repos=knewkarma-io/knewkarma&type=Date&theme=dark" />
      <source media="(prefers-color-scheme: light)" srcset="https://api.star-history.com/svg?repos=knewkarma-io/knewkarma&type=Date" />
      <img alt="Star History Chart" src="https://api.star-history.com/svg?repos=knewkarma-io/knewkarma&type=Date" />
   </picture>
</a>

## License

GPL-3.0+ License © [Ritchie Mwewa](https://gravatar.com/rly0nheart)

